[![Docs](https://raw.githubusercontent.com/aaronater10/sfcparse/main/ext/sfcparse_cover.png)](https://docs.sfcparse.org/)

# sfcparse
The easy to use library for your data, configuration, and save files

[![Functionality-QA-Tests](https://github.com/aaronater10/sfcparse/actions/workflows/sfcparse_functionality_testing.yml/badge.svg)](https://github.com/aaronater10/sfcparse/actions/workflows/sfcparse_functionality_testing.yml)

##### Latest Version: 1.3.2

#

#### sfcparse == Simple File Configuration Parse

Import or Export **custom**, or **industry-common**, data, config, and save files easily for your python program or script!

**Use python data types for your data** (literally use python data types as stored values importing them securely vs just importing a .py file) **in any text file**.

Additionally supports **json**, **yaml**, **ini**, **xml** using the common & native libraries with the idea of simpler abstraction.

Use built-in features for easily formatting your data and other quick and easy tools like getting the hash of a file.


# Tutorials and Docs:
**Quick Start Tutorial Video: [sfcparse Docs](https://docs.sfcparse.org/watch/quick-start)**

**Full Tutorial Videos: [sfcparse Docs](https://docs.sfcparse.org/watch/full-training-series)**

**Official Docs: [sfcparse Docs](https://docs.sfcparse.org/)**

**Latest Updates: [sfcparse Docs](https://docs.sfcparse.org/updates/current-version-updates)**

**Changelog: [sfcparse Docs](https://docs.sfcparse.org/updates/changelog)**

#

### Install
```bash
pip install sfcparse
```

### Cloning the repository

Clone via HTTPS
```bash
git clone https://github.com/aaronater10/sfcparse.git
```

Clone via SSH
```bash
git clone git@github.com:aaronater10/sfcparse.git
```
